onixcheck
=============================

.. autofunction:: onixcheck.validate

.. autoclass:: onixcheck.models.Message
    :members:

.. autoclass:: onixcheck.models.OnixFile
    :members: xml_tree, get_validator

.. autoclass:: onixcheck.models.OnixMeta
    :members: from_tree, from_file

.. autofunction:: onixcheck.utils.iter_files


